/* This file has been prepared for Doxygen automatic documentation generation.*/
/*! \file *********************************************************************
 *
 * \brief  Sourcecode for the CDC task manager.
 *
 * \par Application note:
 *      AVR1907: Xplain Evaluation Board
 *
 * \par Documentation
 *      For comprehensive code documentation, supported compilers, compiler
 *      settings and supported devices see readme.html
 *
 * \author
 *      Atmel Corporation: http://www.atmel.com \n
 *      Support email: avr@atmel.com
 *
 * $Revision: 3119 $
 * $Date: 2010-01-12 15:53:30 +0100 (ti, 12 jan 2010) $  \n
 *
 * Copyright (c) 2010, Atmel Corporation All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 *
 * 3. The name of ATMEL may not be used to endorse or promote products derived
 * from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY ATMEL "AS IS" AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE EXPRESSLY AND
 * SPECIFICALLY DISCLAIMED. IN NO EVENT SHALL ATMEL BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *****************************************************************************/

#include "config.h"
#include "conf_usb.h"
#include "usb_drv.h"
#include "usb_descriptors.h"
#include "usb_standard_request.h"
#include "usb_specific_request.h"
#include "uart_usb_lib.h"
#include "sw_usart.h"
#include "cdc_task.h"


volatile uint8_t cpt_sof;
S_line_coding    line_coding;
extern uint8_t   tx_counter;


/*! \brief This function initializes the hardware resources required for CDC.
 */
void cdc_task_init(void)
{
	SW_USART_init();
	Usb_enable_sof_interrupt();
}


/*! \brief Entry point of the uart cdc management
 *
 *  This function links the software UART and the USB bus.
 */
void cdc_task(void)
{
	
	 /* Check if the device is enumerated.
	  * If it is, run the code.
	  * Otherwise, skip this section. */
	if(Is_device_enumerated()){
		
	        /* Flush buffer if timeout. */
		if(cpt_sof>=NB_MS_BEFORE_FLUSH && tx_counter!=0 ){
			cpt_sof=0;
			uart_usb_flush();
		}
		
		/* Check if something is received on the Soft UART and forward
		 * it the USB UART if necessary. */
		if (SW_USART_Test_Hit()){
			Led_tgl();
			uart_usb_putchar(SW_USART_RX_Buffer_GetByte());
		}
		
		/* Check if something is received on USB UART and forward
		 * it to the Soft UART if necessary. */
		if (uart_usb_test_hit()){
			Led_tgl();
			SW_USART_PutChar(uart_usb_getchar());
		}
		
	}
}


/*! \brief Start of frame action
 *
 *  This function increments the cpt_sof counter each times
 *  the USB Start Of Frame interrupt subroutine is executed (1ms)
 *  Usefull to manage time delays
 */
void sof_action(void)
{
	cpt_sof++;
}
