/* This file has been prepared for Doxygen automatic documentation generation.*/
/*! \file *********************************************************************
 *
 * \brief This file contains the system configuration definition
 *
 * \par Application note:
 *      AVR1907: Xplain Evaluation Board
 *
 * \par Documentation
 *      For comprehensive code documentation, supported compilers, compiler
 *      settings and supported devices see readme.html
 *
 * \author
 *      Atmel Corporation: http://www.atmel.com \n
 *      Support email: avr@atmel.com
 *
 * $Revision: 3123 $
 * $Date: 2010-01-13 14:35:03 +0100 (on, 13 jan 2010) $  \n
 *
 * Copyright (c) 2010, Atmel Corporation All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 *
 * 3. The name of ATMEL may not be used to endorse or promote products derived
 * from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY ATMEL "AS IS" AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE EXPRESSLY AND
 * SPECIFICALLY DISCLAIMED. IN NO EVENT SHALL ATMEL BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *****************************************************************************/


#ifndef _CONFIG_H_
#define _CONFIG_H_

#include "avr_compiler.h"

/*! CPU core frequency in kHz */
#define FOSC 8000

/****************************** MACROS ****************************************/

/*! This macro will reset the internal CPU core clock prescaler */
#define Clear_prescaler()  (CLKPR = (1<<CLKPCE),CLKPR = 0)

/*! This macro configure the internal CPU core clock prescaler value */
#define Set_prescaler(x)   (CLKPR = (1<<CKLPCE),CLKPR = x)

/*! Start PLL with prescaler 4 and test PLL lock bit and wait until lock is set */
#define Start_PLL()        (PLLCSR = (( (0<<PLLP2) | (1<<PLLP1) | (1<<PLLP0) ) | (1<<PLLE)  ))

/*! Macro to wait for the PLL to be ready. */
#define Wait_pll_ready()   while (!(PLLCSR & (1<<PLOCK)))

/* LED Control macros */
#define Led_on()   (PORTB &= ~(1<<PB6))
#define Led_off()  (PORTB |= (1<<PB6))
#define Led_tgl()  (PINB  |= (1<<PB6))
#define Led_init() ((DDRB |= (1<<PB6)),Led_on())

/* Sleep control definitions */
#define IDLE_MODE                        ((0<<SM2)|(0<<SM1)|(0<<SM0))
#define ADC_NOISE_REDUCTION_MODE         ((0<<SM2)|(0<<SM1)|(1<<SM0))
#define POWER_DOWN_MODE                  ((0<<SM2)|(1<<SM1)|(0<<SM0))
#define POWER_SAVE_MODE                  ((0<<SM2)|(1<<SM1)|(1<<SM0))
#define STANDBY_MODE                     ((1<<SM2)|(1<<SM1)|(0<<SM0))
#define EXTENDED_STANDBY_MODE            ((1<<SM2)|(1<<SM1)|(1<<SM0))

/* Macro to enter a sleep mode, uncomment the define to enable sleep. */
#define Enter_sleep(mode)                (SMCR = mode | (1<<SE)),(__sleep()),(SMCR=0)

/* Define to tell if strings should be contained in Flash or RAM. Use RAM for
 * GCC compatability.
 */
#define code  //__flash


/* Byte operation macros */
#define MSB(u16)        (((uint8_t* )&u16)[1])
#define LSB(u16)        (((uint8_t* )&u16)[0])
#define MSW(u32)        (((uint16_t*)&u32)[1])
#define LSW(u32)        (((uint16_t*)&u32)[0])
#define MSB0(u32)       (((uint8_t* )&u32)[3])
#define MSB1(u32)       (((uint8_t* )&u32)[2])
#define MSB2(u32)       (((uint8_t* )&u32)[1])
#define MSB3(u32)       (((uint8_t* )&u32)[0])
#define LSB0(u32)       MSB3(u32)
#define LSB1(u32)       MSB2(u32)
#define LSB2(u32)       MSB1(u32)
#define LSB3(u32)       MSB0(u32)

/*! Define of maximum ms before flushing buffer */
#define NB_MS_BEFORE_FLUSH			50

#endif /* _CONFIG_H_ */

