/* This file has been prepared for Doxygen automatic documentation generation.*/
/*! \file *********************************************************************
 *
 * \brief USB parameters
 *
 *      This file contains the usb parameters that uniquely identify the
 *      application through descriptor tables.
 *
 * \par Application note:
 *      AVR1907: Xplain Evaluation Board
 *
 * \par Documentation
 *      For comprehensive code documentation, supported compilers, compiler
 *      settings and supported devices see readme.html
 *
 * \author
 *      Atmel Corporation: http://www.atmel.com \n
 *      Support email: avr@atmel.com
 *
 * $Revision: 3122 $
 * $Date: 2010-01-13 13:26:22 +0100 (on, 13 jan 2010) $  \n
 *
 * Copyright (c) 2010, Atmel Corporation All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 *
 * 3. The name of ATMEL may not be used to endorse or promote products derived
 * from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY ATMEL "AS IS" AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE EXPRESSLY AND
 * SPECIFICALLY DISCLAIMED. IN NO EVENT SHALL ATMEL BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *****************************************************************************/

#include "config.h"
#include "conf_usb.h"
#include "usb_drv.h"
#include "usb_descriptors.h"
#include "usb_standard_request.h"
#include "usb_specific_request.h"


/*! usb_user_device_descriptor */
code S_usb_device_descriptor usb_dev_desc =
{
	sizeof(usb_dev_desc),
	DEVICE_DESCRIPTOR,
	Usb_write_word_enum_struc(USB_SPECIFICATION),
	DEVICE_CLASS,
	DEVICE_SUB_CLASS,
	DEVICE_PROTOCOL,
	EP_CONTROL_LENGTH,
	Usb_write_word_enum_struc(VENDOR_ID),
	Usb_write_word_enum_struc(PRODUCT_ID),
	Usb_write_word_enum_struc(RELEASE_NUMBER),
	MAN_INDEX,
	PROD_INDEX,
	SN_INDEX,
	NB_CONFIGURATION,
};


/*! usb_user_configuration_descriptor FS */
code S_usb_user_configuration_descriptor usb_conf_desc =
{
	
	{
		sizeof(S_usb_configuration_descriptor),
		CONFIGURATION_DESCRIPTOR,
		Usb_write_word_enum_struc(sizeof(S_usb_user_configuration_descriptor)),
		NB_INTERFACE,
		CONF_NB,
		CONF_INDEX,
		CONF_ATTRIBUTES,
		MAX_POWER,
	}
	,
	{
		sizeof(S_usb_interface_descriptor),
		INTERFACE_DESCRIPTOR,
		INTERFACE0_NB,
		ALTERNATE0,
		NB_ENDPOINT0,
		INTERFACE0_CLASS,
		INTERFACE0_SUB_CLASS,
		INTERFACE0_PROTOCOL,
		INTERFACE0_INDEX,
	}
	,
	{
		0x05,            /* Size */
		CS_INTERFACE,
		CS_HEADER_FD,
		0x10,            /* USB v1.1 */
		0x01,
		0x05,            /* Size */
		CS_INTERFACE,
		CS_CALL_MGM_FD,
		(CALL_MGM_CAP_SELF_MGM | CALL_MGM_CAP_DATA_CLASS),
		INTERFACE1_NB,
		0x04,            /* Size */
		CS_INTERFACE,
		CS_ACM_FD,
		(ACM_CAP_LINE_CODING | ACM_CAP_BREAK),
		0x05,            /* Size */
		CS_INTERFACE,
		CS_UNION_FD,
		INTERFACE0_NB,
		INTERFACE1_NB,
	}
	,
	{
		sizeof(S_usb_endpoint_descriptor),
		ENDPOINT_DESCRIPTOR,
		ENDPOINT_NB_3,
		EP_ATTRIBUTES_3,
		Usb_write_word_enum_struc(EP_SIZE_3),
		EP_INTERVAL_3,
	}
	,
	{
		sizeof(S_usb_interface_descriptor),
		INTERFACE_DESCRIPTOR,
		INTERFACE1_NB,
		ALTERNATE1,
		NB_ENDPOINT1,
		INTERFACE1_CLASS,
		INTERFACE1_SUB_CLASS,
		INTERFACE1_PROTOCOL,
		INTERFACE1_INDEX,
	}
	,
	{
		sizeof(S_usb_endpoint_descriptor),
		ENDPOINT_DESCRIPTOR,
		ENDPOINT_NB_1,
		EP_ATTRIBUTES_1,
		Usb_write_word_enum_struc(EP_SIZE_1),
		EP_INTERVAL_1,
	}
	,
	{
		sizeof(S_usb_endpoint_descriptor),
		ENDPOINT_DESCRIPTOR,
		ENDPOINT_NB_2,
		EP_ATTRIBUTES_2,
		Usb_write_word_enum_struc(EP_SIZE_2),
		EP_INTERVAL_2,
	}
	
};


/*! usb_user_manufacturer_string_descriptor */
code S_usb_manufacturer_string_descriptor usb_user_manufacturer_string_descriptor =
{
	sizeof(usb_user_manufacturer_string_descriptor),
	STRING_DESCRIPTOR,
	USB_MANUFACTURER_NAME
};


/*! usb_user_product_string_descriptor */
code S_usb_product_string_descriptor usb_user_product_string_descriptor =
{
	sizeof(usb_user_product_string_descriptor),
	STRING_DESCRIPTOR,
	USB_PRODUCT_NAME
};


/*! usb_user_serial_number */
code S_usb_serial_number usb_user_serial_number =
{
	sizeof(usb_user_serial_number),
	STRING_DESCRIPTOR,
	USB_SERIAL_NUMBER
};


/*! usb_user_language_id */
code S_usb_language_id usb_user_language_id =
{
	sizeof(usb_user_language_id),
	STRING_DESCRIPTOR,
	Usb_write_word_enum_struc(LANGUAGE_ID)
};


/*! usb_if0_descriptor */
code S_usb_if0_descript usb_if0_descriptor =
{
	sizeof(usb_if0_descriptor),
	STRING_DESCRIPTOR,
	USB_IF0_DESCRIPT
};
