/* This file has been prepared for Doxygen automatic documentation generation.*/
/*! \file *********************************************************************
 *
 * \brief This file contains the user call-back functions corresponding to the
 *        application: CDC DEVICE
 *
 * \par Application note:
 *      AVR1907: Xplain Evaluation Board
 *
 * \par Documentation
 *      For comprehensive code documentation, supported compilers, compiler
 *      settings and supported devices see readme.html
 *
 * \author
 *      Atmel Corporation: http://www.atmel.com \n
 *      Support email: avr@atmel.com
 *
 * $Revision: 3122 $
 * $Date: 2010-01-13 13:26:22 +0100 (on, 13 jan 2010) $  \n
 *
 * Copyright (c) 2010, Atmel Corporation All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 *
 * 3. The name of ATMEL may not be used to endorse or promote products derived
 * from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY ATMEL "AS IS" AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE EXPRESSLY AND
 * SPECIFICALLY DISCLAIMED. IN NO EVENT SHALL ATMEL BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *****************************************************************************/

#ifndef _USB_USER_ENUM_H_
#define _USB_USER_ENUM_H_

#include "config.h"

/****************************** DEFINES ***************************************/

#define CS_INTERFACE              0x24
#define CS_ENDPOINT               0x25

#define CS_HEADER_FD              0x00
#define CS_CALL_MGM_FD            0x01
#define CS_ACM_FD                 0x02
#define CS_DL_MGM_FD              0x03
#define CS_TLF_RING_FD            0x04
#define CS_TLF_CLSRC_FD           0x05
#define CS_UNION_FD               0x06
#define CS_COUNTRY_FD             0x07
#define CS_TLF_OP_MOD_FD          0x08
#define CS_USB_TERM_FD            0x09

/* Call Management Capabilities */
#define CALL_MGM_CAP_SELF_MGM     0x01
#define CALL_MGM_CAP_DATA_CLASS   0x02

/* ACM Capabilities. */
#define ACM_CAP_COMM_FEATURE      0x01
#define ACM_CAP_LINE_CODING       0x02
#define ACM_CAP_BREAK             0x04
#define ACM_CAP_NETWORK_CONN      0x08


#define GET_LINE_CODING           0x21
#define SET_LINE_CODING           0x20
#define SET_CONTROL_LINE_STATE    0x22
#define SEND_BREAK                0x23
#define SEND_ENCAPSULATED_COMMAND 0x00
#define GET_ENCAPSULATED_COMMAND  0x01


/* Structures */

/*! CDC Line coding */
typedef struct{
	uint32_t dwDTERate;
	uint8_t bCharFormat;
	uint8_t bParityType;
	uint8_t bDataBits;
}S_line_coding;


/************************* PROTOTYPES (GLOBAL) ********************************/

/* External dependencies */
extern code S_usb_device_descriptor usb_dev_desc;
extern code S_usb_user_configuration_descriptor usb_conf_desc;
extern code S_usb_user_configuration_descriptor usb_other_conf_desc;
extern code S_usb_device_qualifier_descriptor usb_qual_desc;
extern code S_usb_manufacturer_string_descriptor usb_user_manufacturer_string_descriptor;
extern code S_usb_product_string_descriptor usb_user_product_string_descriptor;
extern code S_usb_serial_number usb_user_serial_number;
extern code S_usb_language_id usb_user_language_id;
extern code S_usb_if0_descript usb_if0_descriptor;

bool  usb_user_read_request(uint8_t, uint8_t);
bool  usb_user_get_descriptor(uint8_t , uint8_t);
void  usb_user_endpoint_init(uint8_t);
void  cdc_get_line_coding();
void  cdc_set_line_coding();
void  cdc_set_control_line_state (void);


#endif

