
/* This file has been prepared for Doxygen automatic documentation generation.*/
/*! \file *********************************************************************
 *
 * \brief This file contains the function declarations
 *
 * \par Application note:
 *      AVR1907: Xplain Evaluation Board
 *
 * \par Documentation
 *      For comprehensive code documentation, supported compilers, compiler
 *      settings and supported devices see readme.html
 *
 * \author
 *      Atmel Corporation: http://www.atmel.com \n
 *      Support email: avr@atmel.com
 *
 * $Revision: 3122 $
 * $Date: 2010-01-13 13:26:22 +0100 (on, 13 jan 2010) $  \n
 *
 * Copyright (c) 2010, Atmel Corporation All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 *
 * 3. The name of ATMEL may not be used to endorse or promote products derived
 * from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY ATMEL "AS IS" AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE EXPRESSLY AND
 * SPECIFICALLY DISCLAIMED. IN NO EVENT SHALL ATMEL BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *****************************************************************************/

#ifndef _USB_TASK_H_
#define _USB_TASK_H_

/****************************** DEFINES ***************************************/

#define EVT_USB_POWERED               1         /* USB plugged */
#define EVT_USB_UNPOWERED             2         /* USB un-plugged */
#define EVT_USB_DEVICE_FUNCTION       3         /* USB in device */
#define EVT_USB_HOST_FUNCTION         4         /* USB in host */
#define EVT_USB_SUSPEND               5         /* USB suspend */
#define EVT_USB_WAKE_UP               6         /* USB wake up */
#define EVT_USB_RESUME                7         /* USB resume */
#define EVT_USB_RESET                 8         /* USB reset */
#define EVT_HOST_SOF                  9         /* Host start of frame sent */
#define EVT_HOST_HWUP                 10        /* Host wakeup detected */
#define EVT_HOST_DISCONNECTION        11        /* The target device is disconencted */

#define USB_MODE_UNDEFINED            0x00
#define USB_MODE_HOST                 0x01
#define USB_MODE_DEVICE               0x02

/****************************** MACROS ****************************************/

#define Usb_send_event(x)               (g_usb_event |= (1<<x))
#define Usb_ack_event(x)                (g_usb_event &= ~(1<<x))
#define Usb_clear_all_event()           (g_usb_event = 0)
#define Is_usb_event(x)                 ((g_usb_event & (1<<x)) ? true : false)
#define Is_not_usb_event(x)             ((g_usb_event & (1<<x)) ? false: true)
#define Is_host_emergency_exit()        (Is_usb_event(EVT_HOST_DISCONNECTION) || Is_usb_event(EVT_USB_DEVICE_FUNCTION))


/************************* PROTOTYPES (GLOBAL) ********************************/

void usb_task_init     (void);
void usb_task          (void);
extern volatile uint16_t g_usb_event;
extern volatile uint8_t private_sof_counter;

#endif /* _USB_TASK_H_ */

